import request from '@/config/axios'

import { config } from '@/config/axios/config'

const { plat_url} = config

export interface AppVO {
  id: number
  appCode: string
  appName: string
  appDomain: string
  apiDomain: string
  appKey: string
  appSecret: string
  appGroup: string
  loadType: string
  icon: string
  orderNum: number
  status: number
  devId: string
  devName: string
  remark: string
  createTime: Date
}

// 查询列表
export const getAppPage = (params: PageParam) => {
  return request.get({ url: '/system/app/page', params })
}

// 获得
export const getApp = (id: number) => {
  return request.get({ url: '/system/app/get?id=' + id })
}

// 查询所拥有应用列表
export const getAppList = () => {
  return request.get({ url: plat_url + '/system/auth/get-app-permission' })
}

// 查询所拥有应用菜单列表
export const getAppMenuList = (id) => {
  return request.get({ url: plat_url + '/system/auth/get-app-menu-permission?id=' + id })
}

// 新增
export const createApp = (data: AppVO) => {
  return request.post({ url: '/system/app/create', data })
}

// 修改
export const updateApp = (data: AppVO) => {
  return request.put({ url: '/system/app/update', data })
}

// 删除
export const deleteApp = (id: number) => {
  return request.delete({ url: '/system/app/delete?id=' + id })
}

// 导出
export const exportApp = (params: AppVO) => {
  return request.download({ url: '/system/app/export-excel', params })
}
